@@ -11,7 +11,9 @@ public class GCubePortalConstants {
 	public static final String USER_MESSAGES_FRIENDLY_URL = "/messages";
 	public static final String VRES_EXPLORE_FRIENDLY_URL = "/explore";
 	public static final String CATALOGUE_FRIENDLY_URL = "/data-catalogue";
-	public static final String AUTHORIZATION_FRIENDLY_URL = "/authorization";
+	public static final String AUTHORIZATION_FRIENDLY_URL = "/authorization";	
+	public static final String MANAGE_USERS_REQUESTS_FRIENDLY_URL = "/manage-user-and-requests";
+	public static final String VRE_ADMINISTRATION_URL = "/administration";
 	
 	public static final String INFRASTRUCTURE_NAME = "infrastructure";  
 	public static final String SCOPES = "scopes";
