@@ -59,8 +59,8 @@ public class PortalContext {
 	protected static final String SCOPE_SEPARATOR = "/";
 
 	private final static String DEFAULT_ROLE = "OrganizationMember";
-	private static final String CONFIGURATION_FOLDER = "conf";
-	private static final String INFRA_PROPERTY_FILENAME = "infrastructure.properties";
+	public static final String CONFIGURATION_FOLDER = "conf";
+	public static final String INFRA_PROPERTY_FILENAME = "infrastructure.properties";
 	private static final String GCUBE_DEV__CONTEXT_PROPERTY_FILENAME = "gcube-dev-context.properties";
 
 	private static final String DEV_USERNAME_ATTR = "user.username";
