@@ -51,7 +51,7 @@ import com.liferay.portlet.expando.model.ExpandoBridge;
 import com.liferay.portlet.expando.util.ExpandoBridgeFactoryUtil;
 
 public class LiferayGroupManager implements GroupManager {
-	
+
 	private static final String DEFAULT_INFRA_NAME = "gcube";
 	public static final String INFRASTRUCTURE_NAME = "infrastructure";
 	/**
@@ -261,9 +261,9 @@ public class LiferayGroupManager implements GroupManager {
 		try {
 			GroupLocalServiceUtil.getGroup(groupId).getParentGroupId();
 		} catch (PortalException e) {
-			throw new GroupRetrievalFault("Group not existing ", e);
+			throw new GroupRetrievalFault("Group id not existing ", groupId);
 		} catch (SystemException e) {
-			e.printStackTrace();
+			throw new GroupRetrievalFault("SystemException or group id not existing ", groupId);
 		}
 		return -1;
 	}
@@ -295,7 +295,7 @@ public class LiferayGroupManager implements GroupManager {
 			g = GroupLocalServiceUtil.getGroup(groupId);
 			return mapLRGroup(g);
 		} catch (PortalException e) {
-			throw new GroupRetrievalFault("Group not existing", e);
+			throw new GroupRetrievalFault("Group not existing", groupId, e);
 		} catch (SystemException e) {
 			e.printStackTrace();
 		}
@@ -419,10 +419,22 @@ public class LiferayGroupManager implements GroupManager {
 	 */
 	@Override
 	public Set<GCubeGroup> listGroupsByUserAndSite(long userId, final String serverName) throws UserRetrievalFault, UserManagementSystemException, GroupRetrievalFault, VirtualGroupNotExistingException {
+		try {
+			return listGroupsByUserAndSiteGroupId(userId, ManagementUtils.getSiteGroupIdFromServletRequest(serverName));
+		} catch (SystemException | PortalException e) {
+			e.printStackTrace();
+		}
+		return null;
+	}
+	/**
+	 * {@inheritDoc}
+	 */
+	@Override
+	public Set<GCubeGroup> listGroupsByUserAndSiteGroupId(long userId, long siteGroupId) throws UserRetrievalFault, UserManagementSystemException, GroupRetrievalFault, VirtualGroupNotExistingException {
 		Set<GCubeGroup> toReturn = new HashSet<>();
 		try {
-			List<VirtualGroup> currSiteVirtualGroups = getVirtualGroups(ManagementUtils.getSiteGroupIdFromServletRequest(serverName));
-					
+			List<VirtualGroup> currSiteVirtualGroups = getVirtualGroups(siteGroupId);
+
 			for (GCubeGroup userGroup : listGroupsByUser(userId)) {
 				if (isVRE(userGroup.getGroupId())) {
 					for (VirtualGroup currSiteVGroup : currSiteVirtualGroups) {
@@ -434,7 +446,7 @@ public class LiferayGroupManager implements GroupManager {
 					}
 				}
 			}
-			
+
 		} catch (Exception e) {
 			e.printStackTrace();
 		}		
@@ -475,7 +487,7 @@ public class LiferayGroupManager implements GroupManager {
 			Group g = GroupLocalServiceUtil.getGroup(groupId);
 			return (g.getParentGroup() == null);
 		} catch (PortalException e1) {
-			throw new GroupRetrievalFault("Group not existing (I think you better check)", e1);
+			throw new GroupRetrievalFault("Group not existing (I think you better check)", groupId, e1);
 		} catch (Exception e) {
 			e.printStackTrace();
 		} 
@@ -492,7 +504,7 @@ public class LiferayGroupManager implements GroupManager {
 				return !isVRE(groupId);
 			}
 		} catch (PortalException e1) {
-			throw new GroupRetrievalFault("Group not existing (I think you better check)", e1);
+			throw new GroupRetrievalFault("Group not existing (I think you better check)", groupId, e1);
 		} catch (Exception e) {
 			e.printStackTrace();
 		} 
@@ -509,7 +521,7 @@ public class LiferayGroupManager implements GroupManager {
 				return (g.getParentGroup().getParentGroup() != null); 
 			}
 		} catch (PortalException e1) {
-			throw new GroupRetrievalFault("Group not existing (I think you better check)", e1);
+			throw new GroupRetrievalFault("Group not existing (I think you better check)", groupId, e1);
 		} catch (Exception e) {
 			e.printStackTrace();
 		} 
@@ -530,7 +542,7 @@ public class LiferayGroupManager implements GroupManager {
 				return "/"+g.getName();
 
 		} catch (PortalException e1) {
-			throw new GroupRetrievalFault("Group not existing (I think you better check)", e1);
+			throw new GroupRetrievalFault("Group not existing (I think you better check)", groupId, e1);
 		} catch (Exception e) {
 			e.printStackTrace();
 		} 
@@ -559,7 +571,7 @@ public class LiferayGroupManager implements GroupManager {
 			} else
 				return null;
 		} catch (PortalException e1) {
-			throw new GroupRetrievalFault("Group not existing (I think you better check)", e1);
+			throw new GroupRetrievalFault("Group not existing (I think you better check)", groupId, e1);
 		} catch (Exception e) {
 			e.printStackTrace();
 		} 
@@ -576,7 +588,7 @@ public class LiferayGroupManager implements GroupManager {
 			g.getExpandoBridge().setAttribute(attributeKey, value);
 			_log.trace("Custom Attribute set OK: " + attributeKey + " value: " + value);
 		} catch (PortalException e1) {
-			throw new GroupRetrievalFault("Group not existing (I think you better check)", e1);
+			throw new GroupRetrievalFault("Group not existing (I think you better check)", groupId, e1);
 		} catch (Exception e) {
 			e.printStackTrace();
 		} 
@@ -601,7 +613,7 @@ public class LiferayGroupManager implements GroupManager {
 					new ServiceContext());
 			return modifiedGroup.getDescription();
 		} catch (PortalException e1) {
-			throw new GroupRetrievalFault("Group not existing (I think you better check)", e1);
+			throw new GroupRetrievalFault("Group not existing (I think you better check)", groupId, e1);
 		} catch (Exception e) {
 			e.printStackTrace();
 		} 
@@ -698,5 +710,26 @@ public class LiferayGroupManager implements GroupManager {
 		return layoutSetLogo;
 	}
 
+	@Override
+	public List<GCubeGroup> getGateways() {
+		List<GCubeGroup> gateways = new ArrayList<GCubeGroup>();
+		try{
+			List<Group> candidateGateways = GroupLocalServiceUtil.getGroups(ManagementUtils.getCompany().getCompanyId(), 0, true);
+
+			// real gateways have no children as well
+			for (Group group : candidateGateways) {
+				List<Group> children = group.getChildren(true);
+				if(children == null || children.isEmpty())
+					if(!group.getFriendlyURL().equals("/guest") && !group.getFriendlyURL().equals("/global")) // created by Liferay 
+						gateways.add(mapLRGroup(group));
+			}
+
+		}catch(Exception e){
+			_log.error("Failed to retrieve the list of gateways", e);
+			return null;
+		}
+		return gateways;
+	}
+
 
 }
