@@ -362,7 +362,7 @@ public class LiferayRoleManager implements RoleManager {
 			throw new TeamRetrievalFault("A Team with this name exists already: name="+teamName);
 		}
 		catch (PortalException e) {
-			throw new GroupRetrievalFault("The groupId could not be found", e);
+			throw new GroupRetrievalFault("The groupId could not be found", groupId, e);
 		} catch (SystemException e) {
 			e.printStackTrace();
 		}
@@ -532,28 +532,15 @@ public class LiferayRoleManager implements RoleManager {
 	@Override
 	public boolean assignTeamToUser(long userId, long teamId)	throws UserManagementSystemException, UserRetrievalFault, TeamRetrievalFault {
 		try {
-			List<Team> currentTeams = TeamLocalServiceUtil.getUserTeams(userId);
-			
-			// add is not supported in the returned list, so we need a workaround
-			List<Team> currentTeamsArrayList = new ArrayList<Team>(currentTeams);
-			Team toAdd = TeamLocalServiceUtil.getTeam(teamId);
-			currentTeamsArrayList.add(toAdd);
-			
-			long[] teamIdstoSet = new long[currentTeamsArrayList.size()];
-			int i = 0;
-			for (Team t : currentTeamsArrayList) {
-				teamIdstoSet[i] = t.getTeamId();
-				i++;
-			}
-			return setUserTeams(userId, teamIdstoSet);
+			_log.debug("Adding user with id " + userId + " to team with id " + teamId);
+			TeamLocalServiceUtil.addUserTeam(userId, teamId);
+			_log.debug("User added to group");
 		} catch (SystemException e) {
 			e.printStackTrace();
-		} catch (PortalException e) {
-			throw new TeamRetrievalFault("The teamId or groupdid does not exists", e);
 		}
 		return false;
 	}
 
-	
+
 
 }
